@@ -1,35 +1,37 @@
 import logging
-import soco
-import soco.alarms
 import pprint
-import tabulate
 import time
 from collections import namedtuple
+from distutils.version import StrictVersion
 from queue import Empty
 from random import randint
-from distutils.version import StrictVersion
+
+import soco
+import soco.alarms
+import tabulate
 
 from .speaker_info import print_speaker_table
 from .utils import (
-    error_and_exit,
-    parameter_type_error,
-    parameter_number_error,
-    zero_parameters,
-    one_parameter,
-    zero_or_one_parameter,
-    one_or_two_parameters,
-    two_parameters,
-    one_or_more_parameters,
-    seconds_until,
-    convert_true_false,
     convert_to_seconds,
-    set_sigterm,
+    convert_true_false,
+    error_and_exit,
+    get_right_hand_speaker,
     get_speaker,
-    save_search,
+    one_or_more_parameters,
+    one_or_two_parameters,
+    one_parameter,
+    parameter_number_error,
+    parameter_type_error,
     read_search,
+    save_search,
+    seconds_until,
+    set_sigterm,
+    two_parameters,
+    zero_one_or_two_parameters,
+    zero_or_one_parameter,
+    zero_parameters,
 )
 
-
 pp = pprint.PrettyPrinter(width=120)
 sonos_max_items = 66000
 
@@ -838,21 +840,47 @@ def remove_from_playlist(speaker, action, args, soco_function, use_local_speaker
         return False
 
 
-@zero_or_one_parameter
+@zero_one_or_two_parameters
 def line_in(speaker, action, args, soco_function, use_local_speaker_list):
     np = len(args)
     if np == 0:
         state = "on" if speaker.is_playing_line_in else "off"
         print(state)
     else:
-        if args[0].lower() == "on":
+        source = args[0]
+        if source.lower() == "off":
+            speaker.stop()
+        elif source.lower() in ["on", "left_input"]:
+            # Switch to the speaker's own line_in
             speaker.switch_to_line_in()
+            speaker.play()
         else:
-            line_in_source = get_speaker(args[0], use_local_speaker_list)
+            line_in_source = None
+            if source.lower() == "right_input":
+                # We want the right-hand speaker of the stereo pair
+                line_in_source = get_right_hand_speaker(speaker)
+            else:
+                # We want to use another speaker's input
+                if np == 2:  # Want to select the input of a stereo pair
+                    the_input = args[1].lower()
+                    if the_input == "right_input":
+                        left_speaker = get_speaker(source, use_local_speaker_list)
+                        line_in_source = get_right_hand_speaker(left_speaker)
+                    elif the_input == "left_input":
+                        line_in_source = get_speaker(source, use_local_speaker_list)
+                    else:
+                        parameter_type_error(
+                            action,
+                            "second parameter (if present) must be 'left_input' or 'right_input'",
+                        )
+                        return False
+                else:
+                    line_in_source = get_speaker(source, use_local_speaker_list)
             if not line_in_source:
-                error_and_exit("Speaker '{}' not found".format(args[0]))
+                error_and_exit("Speaker or input '{}' not found".format(source))
                 return False
             speaker.switch_to_line_in(line_in_source)
+            speaker.play()
     return True
 
 
@@ -1152,6 +1180,7 @@ def search_artists(speaker, action, args, soco_function, use_local_speaker_list)
     artists = ml.get_music_library_information(
         "artists", search_term=name, complete_result=True
     )
+    albums = []
     for artist in artists:
         print()
         print_list_header("Sonos Music Library Albums including Artist:", artist.title)
@@ -1166,6 +1195,12 @@ def search_artists(speaker, action, args, soco_function, use_local_speaker_list)
         # # tracks = ml.get_music_library_information("artists", subcategories=[name, ""], complete_result=True)
         # print_tracks(tracks)
         # print()
+    if len(artists) == 1:
+        # Remove the first (redundant) element from the list before saving
+        albums.pop(0)
+        save_search(albums)
+    elif len(artists) > 1:
+        print("Note: multiple artists found ... search not saved\n")
     return True
 
 
@@ -1188,6 +1223,7 @@ def list_albums(speaker, action, args, soco_function, use_local_speaker_list):
     print_list_header("Sonos Music Library Albums", "")
     print_albums(artists)
     print()
+    save_search(artists)
     return True
 
 
@@ -1247,6 +1283,7 @@ def tracks_in_album(speaker, action, args, soco_function, use_local_speaker_list
         print_list_header("Sonos Music Library Tracks in Album:", album.title)
         print_tracks(tracks)
         print()
+        save_search(tracks)
     return True
 
 
@@ -1341,7 +1378,7 @@ def cue_favourite(speaker, action, args, soco_function, use_local_speaker_list):
     if not speaker.group.mute:
         speaker.group.mute = True
         unmute_group = True
-    if action in ["cfrs", "cue_favourite_radio_station"]:
+    if action in ["cfrs", "cue_favourite_radio_station", "cue_favorite_radio_station"]:
         result = play_favourite_radio(
             speaker, action, args, soco_function, use_local_speaker_list
         )
@@ -1395,7 +1432,9 @@ def last_search(speaker, action, args, soco_function, use_local_speaker_list):
             )
             if items.search_type == "albums":
                 print_albums(items)
-            elif items.search_type == "tracks":
+            # 'artists' search_type is used for tracks when 'tracks_in_album' has
+            #  been used for the search
+            elif items.search_type in ["tracks", "artists"]:
                 print_tracks(items)
             print()
     else:
@@ -1649,6 +1688,7 @@ actions = {
     "st": SonosFunction(search_tracks, ""),
     "tracks_in_album": SonosFunction(tracks_in_album, ""),
     "tia": SonosFunction(tracks_in_album, ""),
+    "lta": SonosFunction(tracks_in_album, ""),
     "list_albums": SonosFunction(list_albums, ""),
     "albums": SonosFunction(list_albums, ""),
     "list_artists": SonosFunction(list_artists, ""),
