@@ -1,7 +1,13 @@
 import argparse
 
-from .utils import error_and_exit, configure_logging, version, configure_common_args
 from .speakers import Speakers
+from .utils import (
+    configure_common_args,
+    configure_logging,
+    docs,
+    error_and_exit,
+    version,
+)
 
 
 def main():
@@ -35,6 +41,10 @@ def main():
         version()
         exit(0)
 
+    if args.docs:
+        docs()
+        exit(0)
+
     configure_logging(args.log)
 
     speaker_list = Speakers()
