@@ -1,11 +1,13 @@
 import datetime
 import logging
 import os
-import sys
 import pickle
-from signal import SIGTERM
+import sys
 from collections.abc import Sequence
+from signal import SIGTERM
+
 import soco
+
 from .__init__ import __version__
 from .speakers import Speakers
 
@@ -84,6 +86,17 @@ def two_parameters(f):
     return wrapper
 
 
+def zero_one_or_two_parameters(f):
+    def wrapper(*args, **kwargs):
+        if len(args[2]) > 2:
+            parameter_number_error(args[1], "zero, one or two")
+            return False
+        else:
+            return f(*args, **kwargs)
+
+    return wrapper
+
+
 def one_or_more_parameters(f):
     def wrapper(*args, **kwargs):
         if len(args[2]) < 1:
@@ -178,6 +191,15 @@ def version():
     print("soco version:     {}".format(soco.__version__))
 
 
+def docs():
+    version = "v{}".format(__version__)
+    if __version__.endswith("+"):
+        url = "https://github.com/avantrec/soco-cli/blob/next_version/README.md"
+    else:
+        url = "https://github.com/avantrec/soco-cli/blob/{}/README.md".format(version)
+    print("Online documentation for {}: {}".format(version, url))
+
+
 # ToDo: Remove with SIGTERM fix
 use_sigterm = False
 
@@ -284,6 +306,25 @@ def get_speaker(name, local=False):
         return soco.discovery.by_name(name)
 
 
+def get_right_hand_speaker(left_hand_speaker):
+    # Get the right-hand speaker of a stereo pair when the
+    # left-hand speaker name/IP is supplied
+    if not left_hand_speaker.is_visible:
+        # If not visible, this is not a left-hand speaker
+        return None
+    else:
+        # Find the speaker which is not visible, for which the
+        # left-hand speaker is the coordinator, and not a Sub
+        for rh_speaker in left_hand_speaker.all_zones:
+            if (
+                rh_speaker.group.coordinator.ip_address == left_hand_speaker.ip_address
+                and not rh_speaker.is_visible
+                and "sub" not in rh_speaker.get_speaker_info()["model_name"].lower()
+            ):
+                return rh_speaker
+        return None
+
+
 # Argument processing
 def configure_common_args(parser):
     """Set up the optional arguments common across the command line programs"""
@@ -314,6 +355,12 @@ def configure_common_args(parser):
         default="NONE",
         help="Set the logging level: 'NONE' (default) |'CRITICAL' | 'ERROR' | 'WARN'| 'INFO' | 'DEBUG'",
     )
+    parser.add_argument(
+        "--docs",
+        action="store_true",
+        default=False,
+        help="Print the URL to the online documentation",
+    )
 
 
 path = os.path.expanduser("~") + "/.soco-cli/"
